// CloudObject.ts
export class CloudObject {
    id: string | null = null;
    className: string;
    createdAt:any;
    updatedAt:any;
    data: Record<string, any> = {};

    constructor(className: string) {
        this.className = className;
    }

    toPointer() {
        return { "__type": "Pointer", "className": this.className, "objectId": this.id };
    }

    set(json: Record<string, any>) {
        Object.keys(json).forEach(key => {
            if (["objectId", "id", "createdAt", "updatedAt", "ACL"].includes(key)) {
                return;
            }
            this.data[key] = json[key];
        });
    }

    get(key: string) {
        return this.data[key] || null;
    }

    async save(): Promise<this> {
        let method = "POST";
        let url = `http://1.94.237.145:1339/parse/classes/${this.className}`;
        
        // 更新
        if (this.id) {
            url += `/${this.id}`;
            method = "PUT";
        }
        
        const body = JSON.stringify(this.data);
        const response = await fetch(url, {
            headers: {
                "accept": "*/*",
                "accept-language": "zh-CN,zh;q=0.9,en;q=0.8,en-GB;q=0.7,en-US;q=0.6",
                "content-type": "text/plain;charset=UTF-8",
                "x-parse-application-id": "ylj",
                "Referer": "http://127.0.0.1:4040/",
                "Referrer-Policy": "strict-origin-when-cross-origin"
            },
            body: body,
            method: method,
            mode: "cors",
            credentials: "omit"
        });

        const result = await response?.json();
        if (result?.error) {
            console.error(result.error);
        }
        if (result?.objectId) {
            this.id = result.objectId;
        }
        return this;
    }

    async destroy(): Promise<boolean> {
        if (!this.id) return false;
        
        const response = await fetch(`http://1.94.237.145:1339/parse/classes/${this.className}/${this.id}`, {
            headers: {
                "accept": "*/*",
                "accept-language": "zh-CN,zh;q=0.9,en;q=0.8,en-GB;q=0.7,en-US;q=0.6",
                "x-parse-application-id": "ylj",
                "Referer": "http://127.0.0.1:4040/",
                "Referrer-Policy": "strict-origin-when-cross-origin"
            },
            body: null,
            method: "DELETE",
            mode: "cors",
            credentials: "omit"
        });

        const result = await response?.json();
        if (result) {
            this.id = null;
        }
        return true;
    }
}

// CloudQuery.ts
export class CloudQuery {
    className: string;
    whereOptions: Record<string, any> = {};

    constructor(className: string) {
        this.className = className;
    }

    greaterThan(key: string, value: any) {
        if (!this.whereOptions[key]) this.whereOptions[key] = {};
        this.whereOptions[key]["$gt"] = value;
    }

    greaterThanAndEqualTo(key: string, value: any) {
        if (!this.whereOptions[key]) this.whereOptions[key] = {};
        this.whereOptions[key]["$gte"] = value;
    }

    lessThan(key: string, value: any) {
        if (!this.whereOptions[key]) this.whereOptions[key] = {};
        this.whereOptions[key]["$lt"] = value;
    }

    lessThanAndEqualTo(key: string, value: any) {
        if (!this.whereOptions[key]) this.whereOptions[key] = {};
        this.whereOptions[key]["$lte"] = value;
    }

    equalTo(key: string, value: any) {
        this.whereOptions[key] = value;
    }

    async get(id: string): Promise<Record<string, any>> {
        const url = `http://1.94.237.145.1339/parse/classes/${this.className}/${id}?`;
        const response = await fetch(url, {
            headers: {
                "accept": "*/*",
                "accept-language": "zh-CN,zh;q=0.9,en;q=0.8,en-GB;q=0.7,en-US;q=0.6",
                "if-none-match": "W/\"127-p6+dUp7xlGAxzyvVsfuvVhMxjPo\"",
                "x-parse-application-id": "ylj",
                "Referer": "http://127.0.0.1:4040/",
                "Referrer-Policy": "strict-origin-when-cross-origin"
            },
            body: null,
            method: "GET",
            mode: "cors",
            credentials: "omit"
        });
        const json = await response?.json();
        return json || {};
    }

    async find(): Promise<CloudObject[]> {
        let url = `http://1.94.237.145:1339/parse/classes/${this.className}?`;

        if (Object.keys(this.whereOptions).length) {
            const whereStr = JSON.stringify(this.whereOptions);
            url += `where=${whereStr}`;
        }

        const response = await fetch(url, {
            headers: {
                "accept": "*/*",
                "accept-language": "zh-CN,zh;q=0.9,en;q=0.8,en-GB;q=0.7,en-US;q=0.6",
                "if-none-match": "W/\"127-p6+dUp7xlGAxzyvVsfuvVhMxjPo\"",
                "x-parse-application-id": "ylj",
                "Referer": "http://127.0.0.1:4040/",
                "Referrer-Policy": "strict-origin-when-cross-origin"
            },
            body: null,
            method: "GET",
            mode: "cors",
            credentials: "omit"
        });
        
        const json = await response?.json();
        let list=json?.results || [];
        let objList=list.map((item:any)=>this.dataToObj(item));
        return objList || [];
    }

    async first(): Promise<CloudObject | null> {
        let url = `http://1.94.237.145:1339/parse/classes/${this.className}?`;

        if (Object.keys(this.whereOptions).length) {
            const whereStr = JSON.stringify(this.whereOptions);
            url += `where=${whereStr}`;
        }

        const response = await fetch(url, {
            headers: {
                "accept": "*/*",
                "accept-language": "zh-CN,zh;q=0.9,en;q=0.8,en-GB;q=0.7,en-US;q=0.6",
                "if-none-match": "W/\"127-p6+dUp7xlGAxzyvVsfuvVhMxjPo\"",
                "x-parse-application-id": "ylj",
                "Referer": "http://127.0.0.1:4040/",
                "Referrer-Policy": "strict-origin-when-cross-origin"
            },
            body: null,
            method: "GET",
            mode: "cors",
            credentials: "omit"
        });

        const json = await response?.json();
        const exists = json?.results?.[0] || null;
        if (exists) {
            let existsObject = this.dataToObj(exists);
            return existsObject;
        }
        return null;
    }

    dataToObj(exists:any):CloudObject{
        let existsObject = new CloudObject(this.className);
            existsObject.set(exists);
            existsObject.id = exists.objectId;
            existsObject.createdAt = exists.createdAt;
            existsObject.updatedAt = exists.updatedAt;
            return existsObject;
        }
    }
// CloudUser.ts
export class CloudUser extends CloudObject {
    constructor() {
        super("_User"); // 假设用户类在Parse中是"_User"
        // 读取用户缓存信息
        let userCacheStr = localStorage.getItem("NCloud/ylj/User")
        if(userCacheStr){
            let userData = JSON.parse(userCacheStr)
            // 设置用户信息
            this.id = userData?.objectId;
            this.sessionToken = userData?.sessionToken;
            this.data = userData; // 保存用户数据
        }
    }

    sessionToken:string|null = ""
    /** 获取当前用户信息 */
    async current() {
        if (!this.sessionToken) {
            console.error("用户未登录");
            return null;
        }
        return this;
        /*const response = await fetch(`http://1.94.237.145:1337/parse/users/me`, {
            headers: {
                "x-parse-application-id": "hcx",
                "x-parse-session-token": this.sessionToken // 使用sessionToken进行身份验证
            },
            method: "GET"
        });

        const result = await response?.json();
        if (result?.error) {
            console.error(result?.error);
            return null;
        }
        return result;*/
    }

    /** 登录 */
    async login(username: string, password: string):Promise<CloudUser|null> {
        const response = await fetch(`http://1.94.237.145:1339/parse/login`, {
            headers: {
                "x-parse-application-id": "ylj",
                "Content-Type": "application/json"
            },
            body: JSON.stringify({ username, password }),
            method: "POST"
        });

        const result = await response?.json();
        if (result?.error) {
            console.error(result?.error);
            return null;
        }
        
        // 设置用户信息
        this.id = result?.objectId;
        this.sessionToken = result?.sessionToken;
        this.data = result; // 保存用户数据
        // 缓存用户信息
        console.log(result)
        localStorage.setItem("NCloud/ylj/User",JSON.stringify(result))
        return this;
    }

    /** 登出 */
    async logout() {
        if (!this.sessionToken) {
            console.error("用户未登录");
            return;
        }

        const response = await fetch(`http://1.94.237.145:1339/parse/logout`, {
            headers: {
                "x-parse-application-id": "ylj",
                "x-parse-session-token": this.sessionToken
            },
            method: "POST"
        });

        const result = await response?.json();
        if (result?.error) {
            console.error(result?.error);
            return false;
        }

        // 清除用户信息
        localStorage.removeItem("NCloud/ylj/User")
        this.id = null;
        this.sessionToken = null;
        this.data = {};
        return true;
    }

    /** 注册 */
    async signUp(username: string, password: string, additionalData: Record<string, any> = {}) {
        const userData = {
            username,
            password,
            ...additionalData // 合并额外的用户数据
        };

        const response = await fetch(`http://1.94.237.145:1339/parse/users`, {
            headers: {
                "x-parse-application-id": "ylj",
                "Content-Type": "application/json"
            },
            body: JSON.stringify(userData),
            method: "POST"
        });

        const result = await response?.json();
        if (result?.error) {
            console.error(result?.error);
            return null;
        }

        // 设置用户信息
        // 缓存用户信息
        console.log(result)
        localStorage.setItem("NCloud/ylj/User",JSON.stringify(result))
        this.id = result?.objectId;
        this.sessionToken = result?.sessionToken;
        this.data = result; // 保存用户数据
        return this;
    }
}